/*********************************************************************
 * Copyright (c) 2023 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/
package org.eclipse.osee.mim;

import java.util.Collection;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;
import org.eclipse.osee.framework.core.data.ArtifactId;
import org.eclipse.osee.framework.core.data.AttributeTypeToken;
import org.eclipse.osee.framework.jdk.core.annotation.Swagger;
import org.eclipse.osee.mim.types.CrossReference;

@Path("crossReference")
@Swagger
public interface CrossReferenceEndpoint {

   @GET()
   @Path("connection/{connectionId}")
   @Produces(MediaType.APPLICATION_JSON)
   Collection<CrossReference> getAll(@PathParam("connectionId") ArtifactId connectionId,
      @QueryParam("pageNum") long pageNum, @QueryParam("count") long pageSize,
      @QueryParam("orderByAttributeType") AttributeTypeToken orderByAttributeType);

   @GET()
   @Path("connection/{connectionId}/{filter}")
   @Produces(MediaType.APPLICATION_JSON)
   Collection<CrossReference> getAllAndFilter(@PathParam("connectionId") ArtifactId connectionId,
      @PathParam("filter") String filter, @QueryParam("pageNum") long pageNum, @QueryParam("count") long pageSize,
      @QueryParam("orderByAttributeType") AttributeTypeToken orderByAttributeType);

   @GET()
   @Path("{id}")
   @Produces(MediaType.APPLICATION_JSON)
   CrossReference get(@PathParam("id") ArtifactId crossReferenceId);
}
